{% load pimptheme %}
<head>
{% load compress %}

{% compress css %}
{% pimp_css 'custom.less'%}
{% pimp_css 'hello.css'%}
{% endcompress %}

{% pimp_css 'hello.css'%}

</head>

<body>
  <h1>Hello World</h1>
{% pimp_img 'hello.jpg'%}
<p>image credits : https://www.flickr.com/photos/trentstrohm/88651219/</p>
<a href="#" id="clickme">Click Me</a>
{% pimp_js 'hello.js'%}
</body>
